==> jc-1.4.0.tar.gz: polyglot/util/TypeOutputStream.h <==
// public class polyglot.util.TypeOutputStream

// class file dependencies
// @dep_class adac05c7137ad26e java_io_ObjectOutputStream
// @dep_class 4026d3144d6654d8 java_io_OutputStream
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 705e5da5ef1a1275 polyglot_util_TypeOutputStream

// header file dependencies
// @dep_header java_io_ObjectOutputStream

#include "java/io/ObjectOutputStream.h"

#ifndef _JC_polyglot_util_TypeOutputStream_H_
#define _JC_polyglot_util_TypeOutputStream_H_

// Forward structure declarations
struct _jc_java_io_OutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Map$object;
struct _jc_java_util_Set$object;
struct _jc_polyglot_types_Type$object;
struct _jc_polyglot_types_TypeObject$object;
struct _jc_polyglot_types_TypeSystem$object;

// Typedefs
typedef struct _jc_polyglot_util_TypeOutputStream$sub_refs	_jc_polyglot_util_TypeOutputStream$sub_refs;
typedef struct _jc_polyglot_util_TypeOutputStream$sub_nonrefs	_jc_polyglot_util_TypeOutputStream$sub_nonrefs;
typedef struct _jc_polyglot_util_TypeOutputStream$refs	_jc_polyglot_util_TypeOutputStream$refs;
typedef struct _jc_polyglot_util_TypeOutputStream$nonrefs	_jc_polyglot_util_TypeOutputStream$nonrefs;
typedef struct _jc_polyglot_util_TypeOutputStream$object	_jc_polyglot_util_TypeOutputStream$object;

typedef const struct _jc_polyglot_util_TypeOutputStream$vmethods	_jc_polyglot_util_TypeOutputStream$vmethods;
typedef const struct _jc_polyglot_util_TypeOutputStream$vtable	_jc_polyglot_util_TypeOutputStream$vtable;
typedef const struct _jc_polyglot_util_TypeOutputStream$vtype	_jc_polyglot_util_TypeOutputStream$vtype;

// Constructors
extern void _jc_polyglot_util_TypeOutputStream$method$_init$f0f7c9948b7544c2(_jc_env *, struct _jc_polyglot_util_TypeOutputStream$object *, struct _jc_java_io_OutputStream$object *, struct _jc_object *, struct _jc_object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_polyglot_util_TypeOutputStream$method$placeHolder$6ef55db28fce69ed(_jc_env *, struct _jc_polyglot_util_TypeOutputStream$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_polyglot_util_TypeOutputStream$method$replaceObject$583f65eb6fc52a9a(_jc_env *, struct _jc_polyglot_util_TypeOutputStream$object *, struct _jc_java_lang_Object$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_util_TypeOutputStream$method_info$placeHolder$6ef55db28fce69ed;
extern _jc_method _jc_polyglot_util_TypeOutputStream$method_info$replaceObject$583f65eb6fc52a9a;

// Virtual methods structure
struct _jc_polyglot_util_TypeOutputStream$vmethods {
	struct _jc_java_lang_Object$object	*(*placeHolder$6ef55db28fce69ed)(_jc_env *, struct _jc_polyglot_util_TypeOutputStream$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*replaceObject$583f65eb6fc52a9a)(_jc_env *, struct _jc_polyglot_util_TypeOutputStream$object *, struct _jc_java_lang_Object$object *);
};

// Vtable
struct _jc_polyglot_util_TypeOutputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_OutputStream$vmethods	java_io_OutputStream;
	_jc_java_io_ObjectOutputStream$vmethods	java_io_ObjectOutputStream;
	_jc_polyglot_util_TypeOutputStream$vmethods	polyglot_util_TypeOutputStream;
};

// Vtype
struct _jc_polyglot_util_TypeOutputStream$vtype {
	_jc_type			type;
	_jc_polyglot_util_TypeOutputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_util_TypeOutputStream$sub_refs {
	struct _jc_object	*ts;
	struct _jc_object	*roots;
	struct _jc_object	*placeHolders;
};

// Reference instance fields (object)
struct _jc_polyglot_util_TypeOutputStream$refs {
    _jc_polyglot_util_TypeOutputStream$sub_refs	polyglot_util_TypeOutputStream;
    _jc_java_io_ObjectOutputStream$sub_refs	java_io_ObjectOutputStream;
    _jc_java_io_OutputStream$sub_refs	java_io_OutputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_util_TypeOutputStream$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_util_TypeOutputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_OutputStream$sub_nonrefs	java_io_OutputStream;
    _jc_java_io_ObjectOutputStream$sub_nonrefs	java_io_ObjectOutputStream;
    _jc_polyglot_util_TypeOutputStream$sub_nonrefs	polyglot_util_TypeOutputStream;
};

// Object instance structure
struct _jc_polyglot_util_TypeOutputStream$object {
	_jc_polyglot_util_TypeOutputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_util_TypeOutputStream$vtype	*vtype;
	_jc_polyglot_util_TypeOutputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_util_TypeOutputStream$vtype _jc_polyglot_util_TypeOutputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_util_TypeOutputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_util_TypeOutputStream$class_object;

#endif	/* _JC_polyglot_util_TypeOutputStream_H_ */

==> jc-1.4.5.tar.gz: polyglot/util/TypeOutputStream.h <==
// public class polyglot.util.TypeOutputStream

// class file dependencies
// @dep_class adac05c7137ad26e java_io_ObjectOutputStream
// @dep_class 4026d3144d6654d8 java_io_OutputStream
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 705e5da5ef1a1275 polyglot_util_TypeOutputStream

// header file dependencies
// @dep_header java_io_ObjectOutputStream

#include "java/io/ObjectOutputStream.h"

#ifndef _JC_polyglot_util_TypeOutputStream_H_
#define _JC_polyglot_util_TypeOutputStream_H_

// Forward structure declarations
struct _jc_java_io_OutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Map$object;
struct _jc_java_util_Set$object;
struct _jc_polyglot_types_Type$object;
struct _jc_polyglot_types_TypeObject$object;
struct _jc_polyglot_types_TypeSystem$object;

// Typedefs
typedef struct _jc_polyglot_util_TypeOutputStream$sub_refs	_jc_polyglot_util_TypeOutputStream$sub_refs;
typedef struct _jc_polyglot_util_TypeOutputStream$sub_nonrefs	_jc_polyglot_util_TypeOutputStream$sub_nonrefs;
typedef struct _jc_polyglot_util_TypeOutputStream$refs	_jc_polyglot_util_TypeOutputStream$refs;
typedef struct _jc_polyglot_util_TypeOutputStream$nonrefs	_jc_polyglot_util_TypeOutputStream$nonrefs;
typedef struct _jc_polyglot_util_TypeOutputStream$object	_jc_polyglot_util_TypeOutputStream$object;

typedef const struct _jc_polyglot_util_TypeOutputStream$vmethods	_jc_polyglot_util_TypeOutputStream$vmethods;
typedef const struct _jc_polyglot_util_TypeOutputStream$vtable	_jc_polyglot_util_TypeOutputStream$vtable;
typedef const struct _jc_polyglot_util_TypeOutputStream$vtype	_jc_polyglot_util_TypeOutputStream$vtype;

// Constructors
extern void _jc_polyglot_util_TypeOutputStream$method$_init$f0f7c9948b7544c2(_jc_env *, struct _jc_polyglot_util_TypeOutputStream$object *, struct _jc_java_io_OutputStream$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_polyglot_util_TypeOutputStream$method$placeHolder$6ef55db28fce69ed(_jc_env *, struct _jc_polyglot_util_TypeOutputStream$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_polyglot_util_TypeOutputStream$method$replaceObject$583f65eb6fc52a9a(_jc_env *, struct _jc_polyglot_util_TypeOutputStream$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_util_TypeOutputStream$method_info$placeHolder$6ef55db28fce69ed;
extern _jc_method _jc_polyglot_util_TypeOutputStream$method_info$replaceObject$583f65eb6fc52a9a;

// Virtual methods structure
struct _jc_polyglot_util_TypeOutputStream$vmethods {
	struct _jc_java_lang_Object$object	*(*placeHolder$6ef55db28fce69ed)(_jc_env *, struct _jc_polyglot_util_TypeOutputStream$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*replaceObject$583f65eb6fc52a9a)(_jc_env *, struct _jc_polyglot_util_TypeOutputStream$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_util_TypeOutputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_OutputStream$vmethods	java_io_OutputStream;
	_jc_java_io_ObjectOutputStream$vmethods	java_io_ObjectOutputStream;
	_jc_polyglot_util_TypeOutputStream$vmethods	polyglot_util_TypeOutputStream;
};

// Vtype
struct _jc_polyglot_util_TypeOutputStream$vtype {
	_jc_type			type;
	_jc_polyglot_util_TypeOutputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_util_TypeOutputStream$sub_refs {
	struct _jc_object	*ts;
	struct _jc_object	*roots;
	struct _jc_object	*placeHolders;
};

// Reference instance fields (object)
struct _jc_polyglot_util_TypeOutputStream$refs {
    _jc_polyglot_util_TypeOutputStream$sub_refs	polyglot_util_TypeOutputStream;
    _jc_java_io_ObjectOutputStream$sub_refs	java_io_ObjectOutputStream;
    _jc_java_io_OutputStream$sub_refs	java_io_OutputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_util_TypeOutputStream$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_util_TypeOutputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_OutputStream$sub_nonrefs	java_io_OutputStream;
    _jc_java_io_ObjectOutputStream$sub_nonrefs	java_io_ObjectOutputStream;
    _jc_polyglot_util_TypeOutputStream$sub_nonrefs	polyglot_util_TypeOutputStream;
};

// Object instance structure
struct _jc_polyglot_util_TypeOutputStream$object {
	_jc_polyglot_util_TypeOutputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_util_TypeOutputStream$vtype	*vtype;
	_jc_polyglot_util_TypeOutputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_util_TypeOutputStream$vtype _jc_polyglot_util_TypeOutputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_util_TypeOutputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_util_TypeOutputStream$class_object;

#endif	/* _JC_polyglot_util_TypeOutputStream_H_ */
